@@ -20,7 +20,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '2.065_006';
+$VERSION        = '2.067_001';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -1394,21 +1394,37 @@ sub Marpa::R2::Scanless::R::terminals_expected {
 
 # Latest and current G1 location are the same
 sub Marpa::R2::Scanless::R::latest_g1_location {
-    my ($self) = @_;
-    return $self->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE]
+    my ($slg) = @_;
+    return $slg->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE]
         ->latest_earley_set();
 }
 
 # Latest and current G1 location are the same
 sub Marpa::R2::Scanless::R::current_g1_location {
-    my ($self) = @_;
-    return $self->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE]
+    my ($slg) = @_;
+    return $slg->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE]
         ->latest_earley_set();
 }
 
 sub Marpa::R2::Scanless::G::rule {
-    my ( $self, @args ) = @_;
-    return $self->[Marpa::R2::Inner::Scanless::G::THICK_G1_GRAMMAR]
+    my ( $slg, @args ) = @_;
+    return $slg->[Marpa::R2::Inner::Scanless::G::THICK_G1_GRAMMAR]
+        ->rule(@args);
+}
+
+sub Marpa::R2::Scanless::G::g1_rule_ids {
+    my ($slg) = @_;
+    return $slg->[Marpa::R2::Inner::Scanless::G::THICK_G1_GRAMMAR]->rule_ids();
+}
+
+sub Marpa::R2::Scanless::G::g0_rule_ids {
+    my ($slg) = @_;
+    return $slg->[Marpa::R2::Inner::Scanless::G::THICK_LEX_GRAMMAR]->rule_ids();
+}
+
+sub Marpa::R2::Scanless::G::g0_rule {
+    my ( $slg, @args ) = @_;
+    return $slg->[Marpa::R2::Inner::Scanless::G::THICK_LEX_GRAMMAR]
         ->rule(@args);
 }
 
